## Version 0.0.14

This new version includes several enhancements and bug fixes to improve the overall performance and user experience of the Llamabot. The Python environment and llama_index versions have been pinned for stability. The chatbot panel app now uses a width of 600 pixels for better UI. The Querybot system message now applies SEMBR for improved readability.

### New Features

- The chatbot panel app now uses a width of 600 pixels for a more user-friendly interface (7e2f05) (Eric Ma)
- Faux chat history of length 6000 tokens is now used as context for further responses in chatbot, enhancing the chatbot's response accuracy (02ef9d) (Eric Ma)
- SEMBR has been applied on the Querybot system message for improved readability (b3c53c) (Eric Ma)

### Bug Fixes

- Fixed UI for a smoother user experience (733759) (Eric Ma)

### Deprecations

- The version of the Python environment has been pinned to 3.9 to ensure compatibility and stability (5db1ae) (Eric Ma)
- The version of llama_index has been pinned for stability (930cbb) (Eric Ma)
- Temporarily settled on an older version of langchain for the time being (af0938) (Eric Ma)

### Refactors

- Refactored Querybot to allow loading of documents later, enhancing the flexibility of the system (3103d9) (Eric Ma)
